@@ -8,66 +8,66 @@ from z3c.dependencychecker.tests.utils import write_source_file_at
 
 
 def test_module_path():
-    obj = BaseModule('/some/path', '/some/path/random/bla')
-    assert obj.path == '/some/path/random/bla'
+    obj = BaseModule("/some/path", "/some/path/random/bla")
+    assert obj.path == "/some/path/random/bla"
 
 
 def test_scan_raises():
-    obj = BaseModule('/some/path', '/some/path/random/bla')
+    obj = BaseModule("/some/path", "/some/path/random/bla")
     with pytest.raises(NotImplementedError):
         obj.scan()
 
 
 def test_create_from_files_raises():
     with pytest.raises(NotImplementedError):
-        BaseModule.create_from_files('/some/path')
+        BaseModule.create_from_files("/some/path")
 
 
 def test_has_test_with_prefix_in_path():
     folder = tempfile.mkdtemp()
-    temporal_file = write_source_file_at((folder, 'blatest'))
+    temporal_file = write_source_file_at((folder, "blatest"))
     python_module = BaseModule(folder, temporal_file)
     assert python_module.testing
 
 
 def test_has_test_in_path():
     folder = tempfile.mkdtemp()
-    temporal_file = write_source_file_at((folder, 'test'))
+    temporal_file = write_source_file_at((folder, "test"))
     python_module = BaseModule(folder, temporal_file)
     assert python_module.testing
 
 
 def test_has_tests_in_path():
     folder = tempfile.mkdtemp()
-    temporal_file = write_source_file_at((folder, 'tests'))
+    temporal_file = write_source_file_at((folder, "tests"))
     python_module = BaseModule(folder, temporal_file)
     assert python_module.testing
 
 
 def test_has_test_in_filename():
     folder = tempfile.mkdtemp()
-    temporal_file = write_source_file_at((folder, 'bla'), filename='test.py')
+    temporal_file = write_source_file_at((folder, "bla"), filename="test.py")
     python_module = BaseModule(folder, temporal_file)
     assert python_module.testing
 
 
 def test_has_tests_in_filename():
     folder = tempfile.mkdtemp()
-    temporal_file = write_source_file_at((folder, 'bla'), filename='tests.py')
+    temporal_file = write_source_file_at((folder, "bla"), filename="tests.py")
     python_module = BaseModule(folder, temporal_file)
     assert python_module.testing
 
 
 def test_has_tests_with_suffix_in_filename():
     folder = tempfile.mkdtemp()
-    temporal_file = write_source_file_at((folder, 'bla'), filename='testsohlala.py')
+    temporal_file = write_source_file_at((folder, "bla"), filename="testsohlala.py")
     python_module = BaseModule(folder, temporal_file)
     assert python_module.testing
 
 
 def test_is_not_a_test_module():
     folder = tempfile.mkdtemp()
-    temporal_file = write_source_file_at((folder, 'bla'), filename='bla.py')
+    temporal_file = write_source_file_at((folder, "bla"), filename="bla.py")
     python_module = BaseModule(folder, temporal_file)
     assert python_module.testing is False
 
@@ -84,6 +84,6 @@ def test_parent_folder_is_test_but_module_not():
     it should be ignored.
     """
     folder = tempfile.mkdtemp()
-    temporal_file = write_source_file_at((folder, 'test', 'bla'), filename='bla.py')
-    python_module = BaseModule(os.path.join(folder, 'test'), temporal_file)
+    temporal_file = write_source_file_at((folder, "test", "bla"), filename="bla.py")
+    python_module = BaseModule(os.path.join(folder, "test"), temporal_file)
     assert python_module.testing is False
