@@ -4,8 +4,8 @@ import tempfile
 from z3c.dependencychecker.modules import DjangoSettings
 from z3c.dependencychecker.tests.utils import write_source_file_at
 
-RANDOM_CODE = 'from zope.component import adapter'
-RANDOM_ASSIGNMENT = 'a = 3'
+RANDOM_CODE = "from zope.component import adapter"
+RANDOM_ASSIGNMENT = "a = 3"
 APPS_ASSIGNMENT_TO_STRING = 'INSTALLED_APPS = "random"'
 APPS_ASSIGNMENT_TO_TUPLE = 'INSTALLED_APPS = ("random1", "random2", )'
 APPS_ASSIGNMENT_TO_LIST = 'INSTALLED_APPS = ["random3", "random4", ]'
@@ -32,25 +32,25 @@ def test_create_from_files_nothing(minimal_structure):
 
 
 def test_create_from_files_single_file_random_name():
-    _, tmp_file = tempfile.mkstemp('.py')
+    _, tmp_file = tempfile.mkstemp(".py")
     modules_found = list(DjangoSettings.create_from_files(tmp_file))
     assert len(modules_found) == 0
 
 
 def test_create_from_files_single_file_settings_name(minimal_structure):
     path, package_name = minimal_structure
-    src_path = os.path.join(path, 'src')
-    write_source_file_at([src_path], filename='some_settings.py')
+    src_path = os.path.join(path, "src")
+    write_source_file_at([src_path], filename="some_settings.py")
     modules_found = list(DjangoSettings.create_from_files(src_path))
     assert len(modules_found) == 1
 
 
 def test_create_from_files_deep_nested(minimal_structure):
     path, package_name = minimal_structure
-    src_path = os.path.join(path, 'src')
+    src_path = os.path.join(path, "src")
     write_source_file_at(
-        [src_path, 'a', 'b', 'c'],
-        filename='anothersettings.py',
+        [src_path, "a", "b", "c"],
+        filename="anothersettings.py",
     )
     modules_found = list(DjangoSettings.create_from_files(src_path))
     assert len(modules_found) == 1
@@ -87,8 +87,8 @@ def test_apps_assignment_to_tuple_details(tmpdir):
         tmpdir,
         APPS_ASSIGNMENT_TO_TUPLE,
     )
-    assert 'random1' in dotted_names
-    assert 'random2' in dotted_names
+    assert "random1" in dotted_names
+    assert "random2" in dotted_names
 
 
 def test_apps_assignment_to_list(tmpdir):
@@ -104,8 +104,8 @@ def test_apps_assignment_to_list_details(tmpdir):
         tmpdir,
         APPS_ASSIGNMENT_TO_LIST,
     )
-    assert 'random3' in dotted_names
-    assert 'random4' in dotted_names
+    assert "random3" in dotted_names
+    assert "random4" in dotted_names
 
 
 def test_apps_assignment_to_list_mixed(tmpdir):
@@ -121,7 +121,7 @@ def test_apps_assignment_to_list_mixed_details(tmpdir):
         tmpdir,
         APPS_ASSIGNMENT_TO_LIST_MIXED,
     )
-    assert dotted_names[0] == 'random5'
+    assert dotted_names[0] == "random5"
 
 
 def test_runner_assignment_to_list(tmpdir):
@@ -145,4 +145,4 @@ def test_apps_assignment_to_string_mixed_details(tmpdir):
         tmpdir,
         TEST_RUNNER_ASSIGNMENT_TO_STRING,
     )
-    assert dotted_names[0] == 'random8'
+    assert dotted_names[0] == "random8"
