@@ -6,19 +6,19 @@ import pytest
 from z3c.dependencychecker.modules import PythonModule
 from z3c.dependencychecker.tests.utils import write_source_file_at
 
-IMPORT = 'import foo'
-IMPORT_MULTIPLE = 'import foo, bar'
-IMPORT_AS = 'import foo as bar'
-IMPORT_AS_MULTIPLE = 'import foo as bar, boo as bla'
+IMPORT = "import foo"
+IMPORT_MULTIPLE = "import foo, bar"
+IMPORT_AS = "import foo as bar"
+IMPORT_AS_MULTIPLE = "import foo as bar, boo as bla"
 
-FROM_IMPORT = 'from foo import bar'
-FROM_IMPORT_MULTIPLE = 'from foo import bar, ber'
-FROM_IMPORT_AS = 'from foo import bar as ber'
-FROM_IMPORT_AS_MULTIPLE = 'from foo import bar as ber, boo as bla'
-FROM_IMPORT_ASTERISK = 'from os import *'
-FROM_IMPORT_DOT = 'from . import something'
-FROM_IMPORT_DOT_DOT = 'from .. import something'
-FROM_IMPORT_DOT_RELATIVE = 'from .local import something'
+FROM_IMPORT = "from foo import bar"
+FROM_IMPORT_MULTIPLE = "from foo import bar, ber"
+FROM_IMPORT_AS = "from foo import bar as ber"
+FROM_IMPORT_AS_MULTIPLE = "from foo import bar as ber, boo as bla"
+FROM_IMPORT_ASTERISK = "from os import *"
+FROM_IMPORT_DOT = "from . import something"
+FROM_IMPORT_DOT_DOT = "from .. import something"
+FROM_IMPORT_DOT_RELATIVE = "from .local import something"
 
 
 def _get_imports_of_python_module(folder, source):
@@ -39,7 +39,7 @@ def test_create_from_files_nothing(minimal_structure):
 
 
 def test_create_from_files_single_file():
-    _, tmp_file = tempfile.mkstemp('.py')
+    _, tmp_file = tempfile.mkstemp(".py")
     modules_found = list(PythonModule.create_from_files(tmp_file))
     assert len(modules_found) == 1
     assert modules_found[0].path == tmp_file
@@ -47,7 +47,7 @@ def test_create_from_files_single_file():
 
 def test_create_from_files_no_init(minimal_structure):
     path, package_name = minimal_structure
-    src_path = os.path.join(path, 'src')
+    src_path = os.path.join(path, "src")
     assert len(os.listdir(src_path)) == 0
 
     write_source_file_at([src_path])
@@ -59,9 +59,9 @@ def test_create_from_files_no_init(minimal_structure):
 
 def test_create_from_files_ignore_no_python(minimal_structure):
     path, package_name = minimal_structure
-    src_path = os.path.join(path, 'src')
-    write_source_file_at([src_path], filename='__init__.py')
-    tempfile.mkstemp('.pt', 'bla', src_path)
+    src_path = os.path.join(path, "src")
+    write_source_file_at([src_path], filename="__init__.py")
+    tempfile.mkstemp(".pt", "bla", src_path)
 
     modules_found = list(PythonModule.create_from_files(src_path))
     assert len(modules_found) == 1
@@ -69,9 +69,9 @@ def test_create_from_files_ignore_no_python(minimal_structure):
 
 def test_create_from_files_found_python(minimal_structure):
     path, package_name = minimal_structure
-    src_path = os.path.join(path, 'src')
-    write_source_file_at([src_path], filename='__init__.py')
-    write_source_file_at([src_path], filename='bla.py')
+    src_path = os.path.join(path, "src")
+    write_source_file_at([src_path], filename="__init__.py")
+    write_source_file_at([src_path], filename="bla.py")
 
     modules_found = list(PythonModule.create_from_files(src_path))
     assert len(modules_found) == 2
@@ -79,13 +79,13 @@ def test_create_from_files_found_python(minimal_structure):
 
 def test_create_from_files_deep_nested(minimal_structure):
     path, package_name = minimal_structure
-    src_path = os.path.join(path, 'src')
-    write_source_file_at([src_path], filename='__init__.py')
-    write_source_file_at([src_path], filename='bla.py')
-    write_source_file_at([src_path, 'a'], filename='__init__.py')
-    write_source_file_at([src_path, 'a'], filename='bla.py')
-    write_source_file_at([src_path, 'a', 'b'], filename='__init__.py')
-    write_source_file_at([src_path, 'a', 'b'], filename='bla.py')
+    src_path = os.path.join(path, "src")
+    write_source_file_at([src_path], filename="__init__.py")
+    write_source_file_at([src_path], filename="bla.py")
+    write_source_file_at([src_path, "a"], filename="__init__.py")
+    write_source_file_at([src_path, "a"], filename="bla.py")
+    write_source_file_at([src_path, "a", "b"], filename="__init__.py")
+    write_source_file_at([src_path, "a", "b"], filename="bla.py")
 
     modules_found = list(PythonModule.create_from_files(src_path))
     assert len(modules_found) == 6
@@ -98,7 +98,7 @@ def test_import(tmpdir):
 
 def test_import_details(tmpdir):
     dotted_names = _get_imports_of_python_module(tmpdir, IMPORT)
-    assert dotted_names == ['foo']
+    assert dotted_names == ["foo"]
 
 
 def test_import_multiple(tmpdir):
@@ -108,7 +108,7 @@ def test_import_multiple(tmpdir):
 
 def test_import_multiple_details(tmpdir):
     dotted_names = _get_imports_of_python_module(tmpdir, IMPORT_MULTIPLE)
-    assert sorted(dotted_names) == ['bar', 'foo']
+    assert sorted(dotted_names) == ["bar", "foo"]
 
 
 def test_import_as(tmpdir):
@@ -118,7 +118,7 @@ def test_import_as(tmpdir):
 
 def test_import_as_details(tmpdir):
     dotted_names = _get_imports_of_python_module(tmpdir, IMPORT_AS)
-    assert dotted_names == ['foo']
+    assert dotted_names == ["foo"]
 
 
 def test_import_as_multiple(tmpdir):
@@ -128,7 +128,7 @@ def test_import_as_multiple(tmpdir):
 
 def test_import_as_multiple_details(tmpdir):
     dotted_names = _get_imports_of_python_module(tmpdir, IMPORT_AS_MULTIPLE)
-    assert sorted(dotted_names) == ['boo', 'foo']
+    assert sorted(dotted_names) == ["boo", "foo"]
 
 
 def test_from_import(tmpdir):
@@ -138,7 +138,7 @@ def test_from_import(tmpdir):
 
 def test_from_import_details(tmpdir):
     dotted_names = _get_imports_of_python_module(tmpdir, FROM_IMPORT)
-    assert dotted_names == ['foo.bar']
+    assert dotted_names == ["foo.bar"]
 
 
 def test_from_import_multiple(tmpdir):
@@ -148,7 +148,7 @@ def test_from_import_multiple(tmpdir):
 
 def test_from_import_multiple_details(tmpdir):
     dotted_names = _get_imports_of_python_module(tmpdir, FROM_IMPORT_MULTIPLE)
-    assert sorted(dotted_names) == ['foo.bar', 'foo.ber']
+    assert sorted(dotted_names) == ["foo.bar", "foo.ber"]
 
 
 def test_from_import_as(tmpdir):
@@ -158,7 +158,7 @@ def test_from_import_as(tmpdir):
 
 def test_from_import_as_details(tmpdir):
     dotted_names = _get_imports_of_python_module(tmpdir, FROM_IMPORT_AS)
-    assert dotted_names == ['foo.bar']
+    assert dotted_names == ["foo.bar"]
 
 
 def test_import_asterisk(tmpdir):
@@ -168,11 +168,11 @@ def test_import_asterisk(tmpdir):
 
 def test_import_asterisk_details(tmpdir):
     dotted_names = _get_imports_of_python_module(tmpdir, FROM_IMPORT_ASTERISK)
-    assert dotted_names == ['os']
+    assert dotted_names == ["os"]
 
 
 @pytest.mark.parametrize(
-    'statement',
+    "statement",
     [
         FROM_IMPORT_DOT,
         FROM_IMPORT_DOT_DOT,
@@ -197,12 +197,12 @@ def test_from_import_as_multiple_details(tmpdir):
         tmpdir,
         FROM_IMPORT_AS_MULTIPLE,
     )
-    assert sorted(dotted_names) == ['foo.bar', 'foo.boo']
+    assert sorted(dotted_names) == ["foo.bar", "foo.boo"]
 
 
 def test_imports_multiple_lines(tmpdir):
     dotted_names = _get_imports_of_python_module(
         tmpdir,
-        'import foo\nimport bar',
+        "import foo\nimport bar",
     )
-    assert sorted(dotted_names) == ['bar', 'foo']
+    assert sorted(dotted_names) == ["bar", "foo"]
