@@ -1,9 +1,11 @@
 import os
 
+import pytest
+
 from z3c.dependencychecker.dotted_name import DottedName
 from z3c.dependencychecker.package import Package
 
-EMPTY_FILE = ''
+EMPTY_FILE = ""
 IGNORE_OTHER_KEYS = """[servers]
 one = "1.2.3.4"
 """
@@ -31,24 +33,27 @@ ignore-packages = 'oops'
 IGNORE_PACKAGES = """[tool.dependencychecker]
 ignore-packages = ['django-toolbar', 'plone.reload']
 """
+ZOPE_MAPPING = """[tool.dependencychecker]
+Zope = ['django-toolbar', 'plone.reload']
+"""
 
 
 def _write_user_config(path, content):
     file_path = os.sep.join(
         [
             path,
-            'pyproject.toml',
+            "pyproject.toml",
         ]
     )
-    with open(file_path, 'w') as config_file:
+    with open(file_path, "w") as config_file:
         config_file.write(content)
 
 
 def _update_requires_txt(path, package_name, packages):
-    file_path = os.sep.join([path, f'{package_name}.egg-info', 'requires.txt'])
-    with open(file_path, 'w') as config_file:
+    file_path = os.sep.join([path, f"{package_name}.egg-info", "requires.txt"])
+    with open(file_path, "w") as config_file:
         for package in packages:
-            config_file.write(f'{package}\n')
+            config_file.write(f"{package}\n")
 
 
 def test_no_file(minimal_structure):
@@ -58,41 +63,19 @@ def test_no_file(minimal_structure):
     assert package.imports.user_mappings == {}
 
 
-def test_empty_file(minimal_structure):
+@pytest.mark.parametrize(
+    "config",
+    (
+        EMPTY_FILE,
+        IGNORE_OTHER_KEYS,
+        ONLY_TOOL_TABLE,
+        EMPTY_DEPENDENCY_TABLE_NESTED,
+        EMPTY_DEPENDENCY_TABLE_MERGED,
+    ),
+)
+def test_valid_configuration(minimal_structure, config):
     path, package_name = minimal_structure
-    _write_user_config(path, EMPTY_FILE)
-    package = Package(path)
-    package.set_user_mappings()
-    assert package.imports.user_mappings == {}
-
-
-def test_ignore_other_keys(minimal_structure):
-    path, package_name = minimal_structure
-    _write_user_config(path, IGNORE_OTHER_KEYS)
-    package = Package(path)
-    package.set_user_mappings()
-    assert package.imports.user_mappings == {}
-
-
-def test_only_tool_table(minimal_structure):
-    path, package_name = minimal_structure
-    _write_user_config(path, ONLY_TOOL_TABLE)
-    package = Package(path)
-    package.set_user_mappings()
-    assert package.imports.user_mappings == {}
-
-
-def test_empty_dependency_table_nested(minimal_structure):
-    path, package_name = minimal_structure
-    _write_user_config(path, EMPTY_DEPENDENCY_TABLE_NESTED)
-    package = Package(path)
-    package.set_user_mappings()
-    assert package.imports.user_mappings == {}
-
-
-def test_empty_dependency_table_merged(minimal_structure):
-    path, package_name = minimal_structure
-    _write_user_config(path, EMPTY_DEPENDENCY_TABLE_MERGED)
+    _write_user_config(path, config)
     package = Package(path)
     package.set_user_mappings()
     assert package.imports.user_mappings == {}
@@ -114,13 +97,13 @@ def test_one_user_mapping(minimal_structure):
         path,
         package_name,
         [
-            'Zope2',
+            "Zope2",
         ],
     )
     package = Package(path)
     package.inspect()
-    five_dotted_name = DottedName('Products.Five')
-    zope_dotted_name = DottedName('Zope2')
+    five_dotted_name = DottedName("Products.Five")
+    zope_dotted_name = DottedName("Zope2")
 
     assert len(package.imports.user_mappings) == 1
     assert zope_dotted_name in package.imports.user_mappings
@@ -138,13 +121,13 @@ def test_filter_out_mappings_on_test(minimal_structure):
     _update_requires_txt(
         path,
         package_name,
-        ['plone.reload', '[test]', 'Zope2'],
+        ["plone.reload", "[test]", "Zope2"],
     )
     package = Package(path)
     package.inspect()
-    five_dotted_name = DottedName('Products.Five')
-    plone_reload_dotted_name = DottedName('plone.reload')
-    zope_dotted_name = DottedName('Zope2')
+    five_dotted_name = DottedName("Products.Five")
+    plone_reload_dotted_name = DottedName("plone.reload")
+    zope_dotted_name = DottedName("Zope2")
 
     assert len(package.imports.user_mappings) == 1
     assert zope_dotted_name in package.imports.user_mappings
@@ -163,14 +146,14 @@ def test_more_user_mappings(minimal_structure):
         path,
         package_name,
         [
-            'Zope2',
-            'Zope4',
+            "Zope2",
+            "Zope4",
         ],
     )
     package = Package(path)
     package.inspect()
-    zope2_dotted_name = DottedName('Zope2')
-    zope4_dotted_name = DottedName('Zope4')
+    zope2_dotted_name = DottedName("Zope2")
+    zope4_dotted_name = DottedName("Zope4")
 
     assert len(package.imports.user_mappings) == 2
     assert zope2_dotted_name in package.imports.user_mappings
@@ -186,12 +169,12 @@ def test_subtables(minimal_structure):
         path,
         package_name,
         [
-            'Zope2',
+            "Zope2",
         ],
     )
     package = Package(path)
     package.inspect()
-    zope2_dotted_name = DottedName('Zope2')
+    zope2_dotted_name = DottedName("Zope2")
 
     assert len(package.imports.user_mappings) == 1
     assert zope2_dotted_name in package.imports.user_mappings
@@ -211,15 +194,24 @@ def test_ignore_packages(minimal_structure):
     _update_requires_txt(
         path,
         package_name,
-        ['Zope2', 'plone.reload', 'django-toolbar'],
+        ["Zope2", "plone.reload", "django-toolbar"],
     )
     package = Package(path)
     package.inspect()
-    django_toolbar = DottedName('django-toolbar')
-    plone_reload = DottedName('plone.reload')
+    django_toolbar = DottedName("django-toolbar")
+    plone_reload = DottedName("plone.reload")
     ignored_packages = package.imports.ignored_packages
 
     assert len(package.imports.user_mappings) == 0
     assert len(ignored_packages) == 2
     assert django_toolbar in ignored_packages
     assert plone_reload in ignored_packages
+
+
+def test_no_ignore_zope_user_mapping(minimal_structure):
+    path, package_name = minimal_structure
+    _write_user_config(path, ZOPE_MAPPING)
+    package = Package(path)
+    package.inspect()
+
+    assert len(package.imports.user_mappings) == 1
